gnome-keyring r1524 - in trunk: . common common/tests daemon egg



Author: nnielsen
Date: Sun Feb  8 00:21:25 2009
New Revision: 1524
URL: http://svn.gnome.org/viewvc/gnome-keyring?rev=1524&view=rev

Log:
Move the general dbus code into our egg folder.

Modified:
   trunk/ChangeLog
   trunk/common/Makefile.am
   trunk/common/gkr-location.c
   trunk/common/tests/Makefile.am
   trunk/daemon/Makefile.am
   trunk/daemon/gkr-daemon-dbus.c
   trunk/egg/Makefile.am
   trunk/egg/egg-dbus.c
   trunk/egg/egg-dbus.h

Modified: trunk/common/Makefile.am
==============================================================================
--- trunk/common/Makefile.am	(original)
+++ trunk/common/Makefile.am	Sun Feb  8 00:21:25 2009
@@ -21,7 +21,6 @@
 libgkr_common_la_SOURCES = \
 	gkr-async.c gkr-async.h \
 	gkr-cleanup.c gkr-cleanup.h \
-	gkr-dbus.c gkr-dbus.h \
 	gkr-location.c gkr-location.h \
 	gkr-location-watch.c gkr-location-watch.h \
 	gkr-unix-signal.c gkr-unix-signal.h \
@@ -29,6 +28,7 @@
 
 libgkr_common_la_LIBADD = \
 	$(top_builddir)/egg/libegg.la \
+	$(top_builddir)/egg/libegg-dbus.la \
 	$(GTHREAD_LIBS) \
 	$(GLIB_LIBS)
 

Modified: trunk/common/gkr-location.c
==============================================================================
--- trunk/common/gkr-location.c	(original)
+++ trunk/common/gkr-location.c	Sun Feb  8 00:21:25 2009
@@ -26,7 +26,8 @@
 #include "gkr-location.h"
 
 #include "gkr-cleanup.h"
-#include "gkr-dbus.h"
+
+#include "egg/egg-dbus.h"
 
 #ifdef WITH_HAL
 #include <libhal.h>
@@ -416,7 +417,7 @@
 	}
 
 	if (pv->dbus_connection != NULL) {
-		gkr_dbus_disconnect_from_mainloop (pv->dbus_connection, NULL);
+		egg_dbus_disconnect_from_mainloop (pv->dbus_connection, NULL);
 		dbus_connection_unref (pv->dbus_connection);
 		pv->dbus_connection = NULL;
 	}
@@ -482,7 +483,7 @@
 		goto failed;
 	}
 	
-	gkr_dbus_connect_with_mainloop (pv->dbus_connection, NULL);
+	egg_dbus_connect_with_mainloop (pv->dbus_connection, NULL);
 	dbus_connection_set_exit_on_disconnect (pv->dbus_connection, FALSE);
 
 	dbus_connection_add_filter (pv->dbus_connection, location_manager_dbus_filter_function, locmgr, NULL);

Modified: trunk/common/tests/Makefile.am
==============================================================================
--- trunk/common/tests/Makefile.am	(original)
+++ trunk/common/tests/Makefile.am	Sun Feb  8 00:21:25 2009
@@ -9,6 +9,7 @@
 
 UNIT_LIBS =  \
 	$(top_builddir)/egg/libegg.la \
+	$(top_builddir)/egg/libegg-dbus.la \
 	$(top_builddir)/common/libgkr-common.la
 
 include $(top_srcdir)/tests/test.make

Modified: trunk/daemon/Makefile.am
==============================================================================
--- trunk/daemon/Makefile.am	(original)
+++ trunk/daemon/Makefile.am	Sun Feb  8 00:21:25 2009
@@ -41,6 +41,7 @@
 	$(top_builddir)/pkcs11/gck/libgck.la \
 	$(top_builddir)/common/libgkr-common.la \
 	$(top_builddir)/gp11/libgp11.la \
+	$(top_builddir)/egg/libegg-dbus.la \
 	$(DAEMON_LIBS) \
 	$(GOBJECT_LIBS) \
 	$(GTHREAD_LIBS) \

Modified: trunk/daemon/gkr-daemon-dbus.c
==============================================================================
--- trunk/daemon/gkr-daemon-dbus.c	(original)
+++ trunk/daemon/gkr-daemon-dbus.c	Sun Feb  8 00:21:25 2009
@@ -26,7 +26,8 @@
 #include "gkr-daemon-util.h"
 
 #include "common/gkr-cleanup.h"
-#include "common/gkr-dbus.h"
+
+#include "egg/egg-dbus.h"
 
 #include "library/gnome-keyring.h"
 #include "library/gnome-keyring-private.h"
@@ -338,7 +339,7 @@
 		unregister_daemon_in_session ();
 		
 		dbus_connection_unregister_object_path (dbus_conn, GNOME_KEYRING_DAEMON_PATH);
-		gkr_dbus_disconnect_from_mainloop (dbus_conn, NULL);
+		egg_dbus_disconnect_from_mainloop (dbus_conn, NULL);
 		dbus_connection_unref (dbus_conn);
 		dbus_conn = NULL;
 	}
@@ -380,7 +381,7 @@
 	
 	gkr_cleanup_register (daemon_dbus_cleanup, NULL);
 
-	gkr_dbus_connect_with_mainloop (dbus_conn, NULL);
+	egg_dbus_connect_with_mainloop (dbus_conn, NULL);
 
 	/* Make sure dbus doesn't kill our app */
 	dbus_connection_set_exit_on_disconnect (dbus_conn, FALSE);

Modified: trunk/egg/Makefile.am
==============================================================================
--- trunk/egg/Makefile.am	(original)
+++ trunk/egg/Makefile.am	Sun Feb  8 00:21:25 2009
@@ -3,6 +3,7 @@
 	libegg.la \
 	libegg-buffer.la \
 	libegg-creds.la \
+	libegg-dbus.la \
 	libegg-secure.la \
 	libegg-secure-entry.la
 
@@ -61,6 +62,17 @@
 libegg_creds_la_SOURCES = \
 	egg-unix-credentials.c egg-unix-credentials.h	
 
+libegg_dbus_la_SOURCES = \
+	egg-dbus.c egg-dbus.h 
+
+libegg_dbus_la_CFLAGS = \
+	$(DBUS_CFLAGS) \
+	$(GLIB_CFLAGS)
+
+libegg_dbus_la_LIBADD = \
+	$(DBUS_LIBS) \
+	$(GLIB_LIBS)
+	
 # -------------------------------------------------------------------
 
 if WITH_TESTS

Modified: trunk/egg/egg-dbus.c
==============================================================================
--- trunk/egg/egg-dbus.c	(original)
+++ trunk/egg/egg-dbus.c	Sun Feb  8 00:21:25 2009
@@ -1,5 +1,5 @@
 /* -*- mode: C; c-file-style: "gnu" -*- */
 /* gkr-dbus.c GLib main loop integration
  *
  * Copyright (C) 2002, 2003 CodeFactory AB
  * Copyright (C) 2005 Red Hat, Inc.
@@ -25,9 +25,7 @@
 
 #include "config.h"
 
-#include "gkr-dbus.h"
-
-#include "gkr-cleanup.h"
+#include "egg-dbus.h"
 
 #include <dbus/dbus.h>
 
@@ -382,7 +380,7 @@
 }
 
 void
-gkr_dbus_connect_with_mainloop (DBusConnection *connection, GMainContext *context)
+egg_dbus_connect_with_mainloop (DBusConnection *connection, GMainContext *context)
 {
 	ConnectionSetup *cs;
   
@@ -410,7 +408,7 @@
 }
 
 void
-gkr_dbus_disconnect_from_mainloop (DBusConnection *connection, GMainContext *context)
+egg_dbus_disconnect_from_mainloop (DBusConnection *connection, GMainContext *context)
 {
 	ConnectionSetup *cs = the_setup;
 	the_setup = NULL;
@@ -1,5 +1,5 @@
 /* -*- mode: C; c-file-style: "gnu" -*- */
-/* gkr-dbus.c GLib main loop integration
+/* egg-dbus.c GLib main loop integration
  *
  * Copyright (C) 2002, 2003 CodeFactory AB

Modified: trunk/egg/egg-dbus.h
==============================================================================
--- trunk/egg/egg-dbus.h	(original)
+++ trunk/egg/egg-dbus.h	Sun Feb  8 00:21:25 2009
@@ -1,5 +1,5 @@
 /* -*- mode: C; c-file-style: "gnu" -*- */
 /* gkr-dbus.h GLib main loop integration
  *
  * Copyright (C) 2002, 2003 CodeFactory AB
  * Copyright (C) 2005 Red Hat, Inc.
@@ -22,14 +22,14 @@
  *
  */
 
-#ifndef GKRDBUS_H_
-#define GKRDBUS_H_
+#ifndef EGGDBUS_H_
+#define EGGDBUS_H_
 
 #include <glib.h>
 #include <dbus/dbus.h>
 
-void gkr_dbus_connect_with_mainloop (DBusConnection *connection, GMainContext *context);
+void egg_dbus_connect_with_mainloop (DBusConnection *connection, GMainContext *context);
 
-void gkr_dbus_disconnect_from_mainloop (DBusConnection *connection, GMainContext *context);
+void egg_dbus_disconnect_from_mainloop (DBusConnection *connection, GMainContext *context);
 
-#endif /*GKRDBUS_H_*/
+#endif /*EGGDBUS_H_*/
@@ -1,5 +1,5 @@
 /* -*- mode: C; c-file-style: "gnu" -*- */
-/* gkr-dbus.h GLib main loop integration
+/* egg-dbus.h GLib main loop integration
  *
  * Copyright (C) 2002, 2003 CodeFactory AB



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]